@@ -5,6 +5,7 @@ use crate::js_utils::JsError;
 use crate::resolvable_future::ResolvableFuture;
 use futures::Future;
 use std::collections::HashMap;
+use std::fmt::{Debug, Formatter};
 use std::pin::Pin;
 use std::sync::{Arc, Mutex};
 
@@ -530,6 +531,12 @@ impl JsValueFacade {
     }
 }
 
+impl Debug for JsValueFacade {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        f.write_str(self.stringify().as_str())
+    }
+}
+
 pub trait JsValueConvertable {
     fn to_js_value_facade(self) -> JsValueFacade;
 }
